@@ -17,7 +17,7 @@ use File::chdir;
 use Path::Class ();
 
 # ABSTRACT: Parallel SSH client
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 sub main
@@ -45,7 +45,9 @@ sub new
     fat        => 0,
     max        => 0,
     count      => 0,
+    summary    => 0,
     files      => [],
+    purge      => 0,
   }, $class;
   
   my @argv = @_;
@@ -54,27 +56,43 @@ sub new
   
   GetOptionsFromArray(
     \@argv,
-    'n'        => \$self->{dry_run},
-    'a'        => sub { $self->{color} = 0 },
-    'l=s'      => \$self->{user},
-    'server'   => \$self->{server},
-    'verbose'  => \$self->{verbose},
-    'serial'   => \$self->{serial},
-    'config=s' => \$config_name,
-    'fat'      => \$self->{fat},
-    'max=s'    => \$self->{max},
-    'file=s'   => $self->{files},
-    'dir=s'    => \$self->{dir},
-    'help|h'   => sub { pod2usage({ -verbose => 2}) },
-    'version'  => sub {
+    'n'         => \$self->{dry_run},
+    'a'         => sub { $self->{color} = 0 },
+    'l=s'       => \$self->{user},
+    'server'    => \$self->{server},
+    'verbose'   => \$self->{verbose},
+    'serial'    => \$self->{serial},
+    'config=s'  => \$config_name,
+    'fat'       => \$self->{fat},
+    'max=s'     => \$self->{max},
+    'file=s'    => $self->{files},
+    'dir=s'     => \$self->{dir},
+    'summary'   => \$self->{summary},
+    'purge'     => \$self->{purge},
+
+    'log'       => sub {
+      $self->{log_dir} = Path::Class::Dir->new(
+        File::HomeDir->my_dist_data('Clustericious-Admin', { create => 1 } ), 
+        'log', 
+        sprintf("%08x.%s", time, $$)
+      );
+    },
+
+    'log-dir=s' => sub { $self->{log_dir} = Path::Class::Dir->new($_[1]) },
+
+    'help|h'    => sub { pod2usage({ -verbose => 2}) },
+    'version'   => sub {
       say STDERR 'App::clad version ', ($App::clad::VERSION // 'dev');
       exit 1;
     },
   ) || pod2usage(1);
   
+  $self->log_dir->mkpath(0,0700) if $self->log_dir;
+
   $self->{config} = Clustericious::Config->new($config_name);
 
   return $self if $self->server;
+  return $self if $self->purge;
   
   # make sure there is at least one cluster specified
   # and that it doesn't look like a command line option
@@ -166,6 +184,11 @@ sub files          { @{ shift->{files} }        }
 sub dir            { shift->{dir}               }
 sub script         { @{ shift->{script} // [] } }
 sub stdin          { defined shift->{stdin}     }
+sub summary        { shift->{summary}           }
+sub log_dir        { shift->{log_dir}           }
+sub purge          { shift->{purge}             }
+sub fail_color     { shift->config->fail_color ( default => 'bold red'    ) }
+sub err_color      { shift->config->err_color  ( default => 'bold yellow' ) }
 sub ssh_command    { shift->config->ssh_command(    default => 'ssh' ) }
 sub ssh_options    { shift->config->ssh_options(    default => [ -o => 'StrictHostKeyChecking=no', 
                                                                  -o => 'BatchMode=yes',
@@ -356,6 +379,7 @@ sub run
   my($self) = @_;
   
   return $self->run_server if $self->server;
+  return $self->run_purge  if $self->purge;
   
   my $ret = 0;
   my @done;
@@ -409,6 +433,8 @@ sub run
   }
   
   $_->recv for @done;
+
+  say "See @{[ $self->log_dir ]} for all logs" if $self->log_dir;
   
   $self->ret;
 }
@@ -419,6 +445,30 @@ sub run_server
   Clustericious::Admin::Server->_server(*STDIN);
 }
 
+sub run_purge
+{
+  my $log_dir = Path::Class::Dir->new(
+    File::HomeDir->my_dist_data('Clustericious-Admin', { create => 1 } ),
+    'log',
+  );
+  
+  return unless -d $log_dir;
+  
+  foreach my $path ($log_dir->children)
+  {
+    if(-d $path)
+    {
+      say "PURGE DIR  $path";
+      $path->rmtree(1, 1);
+    }
+    else
+    {
+      say "PURGE FILE $path";
+      $path->remove;
+    }
+  }
+}
+
 1;
 
 __END__
@@ -433,7 +483,7 @@ App::clad - Parallel SSH client
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
